# Difficulty and Time Perceptions of Preparatory Activities for Quitting Smoking
## Dataset Overview


**Author**: Nele Albers

**Date**: November 2023


This file is meant to give you an overview of the data contained in this folder. The data was collected by Nele Albers, Mark A. Neerincx, and Willem-Paul Brinkman.


### Study

The data was gathered during a study on the online crowdsourcing platform Prolific between 6 September and 16 November 2022. The Human Research Ethics Committee of Delft University of Technology granted ethical approval for the research (Letter of Approval number: 2338). 

In this study, daily smokers who were contemplating or preparing to quit smoking first filled in a prescreening questionnaire and were then invited to a repertory grid study if they passed the prescreening. In the repertory grid study, participants were asked to divide sets of 3 preparatory activities for quitting smoking into two subgroups. Afterward, they rated all preparatory activities on the perceived ease of doing them and the perceived required time to do them. Participants also provided a free-text response on what makes some activities more difficult than others.

The study was pre-registered in the Open Science Framework (OSF): https://osf.io/cax6f. This pre-registration describes the study setup, measures, etc. Note that this dataset contains only part of the collected data: the data related to studying the perceived difficulty of preparatory activities.

The file "Preparatory_Activity_Formulations.xlsx" contains the formulations of the 44 preparatory activities used in this study.


### Data

This dataset contains three types of data:

- **Data from participants' Prolific profiles**. This includes, for example, the age, gender, weekly exercise amount, and smoking frequency.
- **Data from a prescreening questionnaire**. This includes, for example, the stage of change for quitting smoking and whether people previously tried to quit smoking.
- **Data from the repertory grid study**. This includes the ratings of the 44 activities on ease and required time as well as the free-text responses on what makes some activities more difficult than others.

There is for each data file a file that explains each data column. For example, the file "prolific_profile_data_explanation.xlsx" contains the column explanations for the data gathered from participants' Prolific profiles.

Each data file contains a column called "rand_id" that can be used to link the data from the data files.


### Files 

This folder contains the following files:
- get_participant_characteristics.py: Python code used to preprocess and anonymize the data from the prescreening questionnaire and Prolific profiles.
- get_participant_characteristics_output.txt: Output file generated when running the above file.
- Preparatory_Activity_Formulations.xlsx: Formulations of the 44 preparatory activities used in the study.
- preprocess_ratings_data.py: Python code to preprocess and anonymize the activity ratings data from the repertory grid study.
- preprocess_ratings_data_output.txt: Output file generated when running the above file.
- prescreening_questionnaire_data_explanation.xlsx: File that contains the column explanations for the data gathered in the prescreening questionnaire.
- prescreening_questionnaire_final_participants_only_anonym.csv: Prescreening questionnaire data from the 144 participants who successfully completed the repertory grid study.
- prescreening_questionnaire_paid_grouping_participants_only_anonym.csv: Prescreening questionnaire data from the 144 participants who successfully completed the repertory grid study + 3 participants who provided non-sensible group labels in the repertory grid study but were still paid for the repertory grid study.
- prolific_profile_data_explanation.xlsx: File that contains the column explanations for the data from the Prolific profiles of participants.
- prolific_profile_data_final_participants_only_anonym.csv: Prolific profile data from the 144 participants who successfully completed the repertory grid study.
- prolific_profile_data_paid_grouping_participants_only_anonym.csv: Prolific profile data from the 144 participants who successfully completed the repertory grid study + 3 participants who provided non-sensible group labels in the repertory grid study but were still paid for the repertory grid study.
- ratings_data_anonym.csv: Activity ratings data from the repertory grid study.
- ratings_data_explanation.xlsx: File that contains the column explanations for the data from the repertory grid study.
- README.md/README.pdf: This README-file.
